@@ -1,13 +1,11 @@
 import os
 from datetime import datetime
-from contextlib import contextmanager
 import logging
 import re
 import urllib2
 from urlparse import urlsplit
 
 from BeautifulSoup import BeautifulSoup
-import formencode as fe
 from formencode import validators as fev
 import html2text
 from ming.utils import LazyProperty
@@ -15,6 +13,7 @@ from pylons import tmpl_context as c
 from pylons import app_globals as g
 from tg import (
         expose,
+        flash,
         redirect,
         validate,
         )
@@ -25,13 +24,16 @@ from tg.decorators import (
 
 from allura.controllers import BaseController
 from allura.lib import helpers as h
-from allura.lib.decorators import require_post
+from allura.lib.decorators import require_post, task
 from allura import model as M
 
 from forgewiki.wiki_main import ForgeWikiApp
 from forgewiki import model as WM
 
-from forgeimporters.base import ToolImporter
+from forgeimporters.base import (
+        ToolImporter,
+        ToolImportForm,
+        )
 from forgeimporters.google import GoogleCodeProjectExtractor
 
 TARGET_APP_ENTRY_POINT_NAME = 'Wiki'
@@ -40,37 +42,42 @@ DATE_FORMAT = '%a %b %d %H:%M:%S %Y'
 log = logging.getLogger(__name__)
 
 
-@contextmanager
-def no_notifications(project):
-    try:
-        project.notifications_disabled = True
-        yield
-    finally:
-        project.notifications_disabled = False
+@task(notifications_disabled=True)
+def import_tool(**kw):
+    GoogleCodeWikiImporter().import_tool(c.project, c.user, **kw)
 
 
-class GoogleCodeWikiImportSchema(fe.Schema):
+class GoogleCodeWikiImportForm(ToolImportForm):
     gc_project_name = fev.UnicodeString(not_empty=True)
-    mount_point = fev.UnicodeString()
-    mount_label = fev.UnicodeString()
 
 
 class GoogleCodeWikiImportController(BaseController):
+    def __init__(self):
+        self.importer = GoogleCodeWikiImporter()
+
+    @property
+    def target_app(self):
+        return self.importer.target_app
+
     @with_trailing_slash
     @expose('jinja:googlecodewikiimporter:templates/index.html')
     def index(self, **kw):
-        return {}
+        return dict(importer=self.importer,
+                target_app=self.target_app)
 
     @without_trailing_slash
     @expose()
     @require_post()
-    @validate(GoogleCodeWikiImportSchema(), error_handler=index)
+    @validate(GoogleCodeWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, gc_project_name, mount_point, mount_label, **kw):
-        c.project.set_tool_data('google-code', project_name=gc_project_name)
-        app = GoogleCodeWikiImporter().import_tool(c.project, c.user,
+        import_tool.post(
+                project_name=gc_project_name,
                 mount_point=mount_point,
-                mount_label=mount_label)
-        redirect(app.url())
+                mount_label=mount_label,
+                )
+        flash('Wiki import has begun. Your new wiki will be available '
+                'when the import is complete.')
+        redirect(c.project.url() + 'admin/')
 
 
 class GoogleCodeWikiComment(object):
@@ -190,18 +197,17 @@ class GoogleCodeWikiImporter(ToolImporter):
         """
         extractor = GoogleCodeWikiExtractor(project_name)
         default_wiki_page_name = extractor.get_default_wiki_page_name()
-        with no_notifications(project):
-            app = project.install_app(
-                    TARGET_APP_ENTRY_POINT_NAME,
-                    mount_point=mount_point or 'wiki',
-                    mount_label=mount_label or 'Wiki',
-                    )
-            with h.push_context(project._id,
-                    mount_point=app.config.options.mount_point):
-                for page in self.get_pages(extractor):
-                    self.create_page(page)
-                    if page.name == default_wiki_page_name:
-                        app.root_page_name = page.name
+        app = project.install_app(
+                TARGET_APP_ENTRY_POINT_NAME,
+                mount_point=mount_point or 'wiki',
+                mount_label=mount_label or 'Wiki',
+                )
+        with h.push_context(project._id,
+                mount_point=app.config.options.mount_point):
+            for page in self.get_pages(extractor):
+                self.create_page(page)
+                if page.name == default_wiki_page_name:
+                    app.root_page_name = page.name
         g.post_event('project_updated')
         return app
 
