@@ -218,25 +218,18 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
         self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
 
     @with_wiki
-    @patch('googlecodewikiimporter.importer.GoogleCodeWikiImporter')
-    def test_create(self, importer):
-        from allura import model as M
-        importer = importer.return_value
-        importer.import_tool.return_value = Mock()
-        importer.import_tool.return_value.url.return_value = '/p/test/mymount'
+    @patch('googlecodewikiimporter.importer.import_tool')
+    def test_create(self, import_tool):
         params = dict(gc_project_name='myproject',
                 mount_label='mylabel',
                 mount_point='mymount',
                 )
         r = self.app.post('/p/test/admin/wiki/_importer/create', params,
                 status=302)
-        project = M.Project.query.get(shortname='test')
-        self.assertEqual(r.location, 'http://localhost/p/test/mymount')
-        self.assertEqual(project.get_tool_data('google-code', 'project_name'),
-                'myproject')
-        self.assertEqual(project._id, importer.import_tool.call_args[0][0]._id)
-        self.assertEqual(u'mymount', importer.import_tool.call_args[1]['mount_point'])
-        self.assertEqual(u'mylabel', importer.import_tool.call_args[1]['mount_label'])
+        self.assertEqual(r.location, 'http://localhost/p/test/admin/')
+        self.assertEqual(u'mymount', import_tool.post.call_args[1]['mount_point'])
+        self.assertEqual(u'mylabel', import_tool.post.call_args[1]['mount_label'])
+        self.assertEqual(u'myproject', import_tool.post.call_args[1]['project_name'])
 
 
 class TestGoogleCodeWikiExtractor(TestCase):
